/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2006. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("com.ibm.rational.report.web.core.app.internal.common.PaginationControl");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("net.jazz.ajax.toolbox.lang.internal.Lang");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");

var CommonMessages	    	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var Util					= com.ibm.rational.report.web.core.app.internal.Util;

(function() {

var checkNotNull 		= net.jazz.ajax.toolbox.lang.checkNotNull;
var checkNonNegative 	= net.jazz.ajax.toolbox.lang.checkNonNegative;
var checkNotEmpty 		= net.jazz.ajax.toolbox.lang.checkNotEmpty;

/**
 * A meta-area widget that allows the user to manipulate query results by
 * navigating between query result pages and by performing textual filters on a
 * query page.
 */
 dojo.declare(
	"com.ibm.rational.report.web.core.app.internal.common.PaginationControl",
	[dijit._Widget, dijit._Templated],
	{
		templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/templates/PaginationControl.html"),
		
		constructor: function(args) {
			this.viewer = args.viewer;
			this.size = 50;
			this.startIndex	= 1;
			this.endIndex = (this.startIndex + this.size - 1);
			this.maxIndex = -1;
		},			
		// populate the template with data, connect events, and show initial
		// sub-tab
		postCreate: function(value) {
			
			this.pageSize.value = 50;
			this.size = parseInt(this.pageSize.value, 10);
			var self = this; 
			
			this.previousText = document.createTextNode(CommonMessages.PREVIOUS_LABEL);
			this.nextText = document.createTextNode(CommonMessages.NEXT_LABEL);
			
			this.previousLink = document.createElement("A");
			this.previousLink.setAttribute("title",CommonMessages.PREVIOUS_PAGE_TOOLTIP);
			this.previousLink.setAttribute("href","#");
			this.previousLink.appendChild(document.createTextNode(CommonMessages.PREVIOUS_LABEL));
			dojo.connect(this.previousLink ,"onclick",
				function(e) {
					e.preventDefault();
					self.gotoPrevious();
				}
			);
			
			this.nextLink = document.createElement("A");
			this.nextLink.setAttribute("title",CommonMessages.NEXT_PAGE_TOOLTIP);
			this.nextLink.setAttribute("href","#");
			this.nextLink.appendChild(document.createTextNode(CommonMessages.NEXT_LABEL));
			dojo.connect(this.nextLink ,"onclick",
				function(e) {
					e.preventDefault();
					self.gotoNext();
				}
			);
			
			
			this.setPreviousLink(false);
			this.setNextLink(false);
			
			this.pageSize.title = CommonMessages.SELECT_PAGE_SIZE_TOOLTIP;
			 
			dojo.connect(this.pageSize, "onchange",
				function(e) {
					e.preventDefault();
					self.size = parseInt(self.pageSize.value, 10);
					self.update();
				}
			);
			
			Util.removeChildren(this.itemsPerLabel);
			this.itemsPerLabel.appendChild(document.createTextNode(CommonMessages.ITEMS_PER_PAGE_LABEL + ": "));	
		},
		
		setPreviousLink : function (enabled) {
			var elem = (enabled)? this.previousLink : this.previousText;
			Util.removeChildren(this.previousLinkContainer);
			this.previousLinkContainer.appendChild(elem);
		},
		
		setNextLink : function (enabled) {
			var elem = (enabled)? this.nextLink:this.nextText;
			Util.removeChildren(this.nextLinkContainer);
			this.nextLinkContainer.appendChild(elem);
		},

		gotoPrevious : function() {
			this.startIndex = this.startIndex - this.size;
			if (this.startIndex <= 1) {
				this.startIndex = 1;
				this.setPreviousLink(false);
			}
			this.endIndex = (this.startIndex + this.size - 1);
			this.update();
		},	
		
		gotoNext : function() {
			this.startIndex = this.startIndex + this.size;
			this.endIndex = (this.startIndex + this.size - 1);
			this.update();
		},	
		
		update : function () {
			this.setPageInfo(this.startIndex,this.endIndex);
			this.viewer.displayContent();
			this.setNextLink(false);
			this.setPreviousLink(false);
		},
		
		setPageInfo: function(start, end) {
			this.startIndex = start;
			this.endIndex = end;
			this.pageInfo.innerHTML = "<b>" +  start + "</b> - <b>" + end + "</b>";
		},
		
		setMaxIndex : function(value) {
			this.maxIndex = value;
		},
		
		getMaxIndex : function() {
			return this.maxIndex;
		},
		
		setStartIndex : function(value) {
			this.startIndex = value;
		},
		
		getStartIndex : function(value) {
			return this.startIndex;
		},
		
		setEndIndex : function(value) {
			this.endIndex = value;
		},
		
		getEndIndex : function(value) {
			return this.endIndex;
		},
		
		getPageSize : function() {
			return this.size;
		}
	});

})();