/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.report.ReportParameterViewer");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.rational.report.web.core.app.view.report.ReportParameterWidget");
dojo.require("com.ibm.rational.report.web.core.app.view.report.ReportParameterManager");
dojo.require("com.ibm.rational.report.web.core.app.internal.Util");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.report", "Messages");

var CommonMessages			= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var ReportMessages			= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.report", "Messages");
var Util					= com.ibm.rational.report.web.core.app.internal.Util;
var TWISTY_OPEN_LIGHT		= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/icons/arrow_down.gif");
var TWISTY_OPEN				= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/icons/arrow_opened_hov.gif");
var TWISTY_CLOSED_LIGHT		= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/icons/arrow_right.gif");
var TWISTY_CLOSED			= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/icons/arrow_closed_hov.gif");

/**
 * Displays the Export Report dialog.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.report.ReportParameterViewer",
	[dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/report/templates/ReportParameterViewer.html"),
	
	constructor: function(args) {
		this._paramManager = args.paramManager;
		this._paramWidgetsMap = new Object();
		this._inEditMode = false;
	},
	
	postCreate: function() {
		var self = this;
		var paramNames = this._paramManager.getParamNames();
		for(var i in paramNames){
			var name = paramNames[i];
			if(!this._paramManager.isHidden(name)){
				var paramWidget = new com.ibm.rational.report.web.core.app.view.report.ReportParameterWidget(
					{paramManager: this._paramManager, paramName: name});
				this.parameterWidgetContainer.appendChild(paramWidget.domNode);
				this._paramWidgetsMap[name] = paramWidget;
			}
		}
		this.parameterOuterDiv.title = ReportMessages.REPORT_PARAM_EXPAND_CLOSE_TOOLTIP;
		Util.removeChildren(this.twistyLink);
		this.twistyIcon = document.createElement("img");
		this.twistyIcon.src = TWISTY_CLOSED_LIGHT;
		this.twistyLink.appendChild(this.twistyIcon);
		if (dojo.isIE) {
			this.twistyIcon.align = "bottom";
		} else if (dojo.isMozilla) {
			this.twistyIcon.align = "top";
		}	
		this.twistyLink.appendChild(document.createTextNode(ReportMessages.REPORT_PARAM_SECTION_TEXT));
		dojo.connect(this.parameterOuterDiv, "onmouseover",
			function(e) {
				e.preventDefault();
				self._mouseOver();
			}
		);
		dojo.connect(this.parameterOuterDiv, "onmouseout",
			function(e) {
				e.preventDefault();
				self._mouseOut();
			}
		);
//		dojo.connect(this.parameterOuterDiv, "onclick",
//			function(e) {
//				e.preventDefault();
//				self._switchEditMode();
//			}
//		);
		dojo.connect(this.twistyLink, "onclick",
			function(e) {
				e.preventDefault();
				self._switchEditMode();
			}
		);
		if(!this._paramManager.hasAllRequiredValues()) this._enterEditMode();
	},
	
	_mouseOver: function() {
		if(this._inEditMode) return;
		this.parameterOuterDiv.className = "hoverParameterOuterDiv";
		this.parameterDiv.className = "hoverParameterDiv";
		this.twistyLink.className = "twistyHover";
		this.topDarkLine.className = "compactDarkRule";
		this.twistyIcon.src = TWISTY_CLOSED;
		var paramNames = this._paramManager.getParamNames();
		for(var i in paramNames){
			var name = paramNames[i];
			this._paramWidgetsMap[name].mouseOver();
		}
	},
	
	_mouseOut: function() {
		if(this._inEditMode) return;
		this.parameterOuterDiv.className = "noHoverParameterOuterDiv";
		this.parameterDiv.className = "noHoverParameterDiv";
		this.twistyLink.className = "twistyNoHover";
		this.topDarkLine.className = "compactLightRule";
		this.twistyIcon.src = TWISTY_CLOSED_LIGHT;
		var paramNames = this._paramManager.getParamNames();
		for(var i in paramNames){
			var name = paramNames[i];
			this._paramWidgetsMap[name].mouseOut();
		}
	},
	
	_switchEditMode: function() {
		if(this._inEditMode) this._exitEditMode();
		else this._enterEditMode();
	},
	
	_enterEditMode: function() {
		if(this._inEditMode) return;
		this._mouseOver();
		this._inEditMode = true;
		this.parameterOuterDiv.title = "";
		this.twistyIcon.src = TWISTY_OPEN_LIGHT;
		
		var topRunButton = document.createElement("a");
		topRunButton.appendChild(document.createTextNode(ReportMessages.REPORT_PARAM_RUN_BUTTON));
		topRunButton.href = "javascript:{}";
		topRunButton.className = "toplink";
		var topSep = document.createElement("a");
		topSep.appendChild(document.createTextNode("|"));
		topSep.className = "separator";
		var topCancelButton = document.createElement("a");
		topCancelButton.appendChild(document.createTextNode(ReportMessages.REPORT_PARAM_CANCEL_BUTTON));
		topCancelButton.href = "javascript:{}";
		topCancelButton.className = "toplink";
		this.topActionDiv.appendChild(topRunButton);
		this.topActionDiv.appendChild(topSep);
		this.topActionDiv.appendChild(topCancelButton);
		
		var bottomDarkLine = document.createElement("div");
		bottomDarkLine.className = "compactDarkRule";
		var bottomInvisibleLine = document.createElement("div");
		bottomInvisibleLine.className = "bottomCompactInvisibleDarkRule";
		var bottomRunButton = document.createElement("a");
		bottomRunButton.appendChild(document.createTextNode(ReportMessages.REPORT_PARAM_RUN_BUTTON));
		bottomRunButton.href = "javascript:{}";
		bottomRunButton.className = "bottomlink";
		var bottomSep = document.createElement("a");
		bottomSep.appendChild(document.createTextNode("|"));
		bottomSep.className = "separator";
		var bottomCancelButton = document.createElement("a");
		bottomCancelButton.appendChild(document.createTextNode(ReportMessages.REPORT_PARAM_CANCEL_BUTTON));
		bottomCancelButton.href = "javascript:{}";
		bottomCancelButton.className = "bottomlink";
		this.bottomActionDiv.appendChild(bottomDarkLine);
		this.bottomActionDiv.appendChild(bottomInvisibleLine);
		this.bottomActionDiv.appendChild(bottomRunButton);
		this.bottomActionDiv.appendChild(bottomSep);
		this.bottomActionDiv.appendChild(bottomCancelButton);
		this.bottomActionDiv.className = "actionDiv";
		
		var paramNames = this._paramManager.getParamNames();
		for(var i in paramNames){
			var name = paramNames[i];
			this._paramWidgetsMap[name].displayInEditMode();
		}
		
		var self = this;
		dojo.connect(topRunButton, "onclick",
			function(e) {
				e.preventDefault();
				self._handleRun();
			}
		);
		dojo.connect(topCancelButton, "onclick",
			function(e) {
				e.preventDefault();
				self._handleCancel();
			}
		);
		dojo.connect(bottomRunButton, "onclick",
			function(e) {
				e.preventDefault();
				self._handleRun();
			}
		);
		dojo.connect(bottomCancelButton, "onclick",
			function(e) {
				e.preventDefault();
				self._handleCancel();
			}
		);
	},
	
	_exitEditMode: function() {
		this._inEditMode = false;
		this.parameterOuterDiv.title = ReportMessages.REPORT_PARAM_EXPAND_CLOSE_TOOLTIP;
		Util.removeChildren(this.topActionDiv);
		Util.removeChildren(this.bottomActionDiv);
		this.bottomActionDiv.className = "invisibleActionDiv";
		var paramNames = this._paramManager.getParamNames();
		for(var i in paramNames){
			var name = paramNames[i];
			this._paramWidgetsMap[name].displayInReadMode();
		}
		this._mouseOut();
	},
	
	_handleRun: function() {
		if(this._paramManager.hasAllRequiredValues()) this._exitEditMode();
		dojo.publish("com.ibm.rational.report.runReport."+this._paramManager.report.itemId);
	},
	
	_handleCancel: function() {
		this._paramManager.resetCurrentValues();
		this._exitEditMode();
		if(this._paramManager.hasAllRequiredValues())
			dojo.publish("com.ibm.rational.report.runReport."+this._paramManager.report.itemId);
	}

});

})();